@@ -1,16 +1,20 @@
-/*======================================================================
-
-  This file is part of the elastix software.
-
-  Copyright (c) University Medical Center Utrecht. All rights reserved.
-  See src/CopyrightElastix.txt or http://elastix.isi.uu.nl/legal.php for
-  details.
-
-     This software is distributed WITHOUT ANY WARRANTY; without even
-     the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
-     PURPOSE. See the above copyright notices for more information.
-
-======================================================================*/
+/*=========================================================================
+ *
+ *  Copyright UMC Utrecht and contributors
+ *
+ *  Licensed under the Apache License, Version 2.0 (the "License");
+ *  you may not use this file except in compliance with the License.
+ *  You may obtain a copy of the License at
+ *
+ *        http://www.apache.org/licenses/LICENSE-2.0.txt
+ *
+ *  Unless required by applicable law or agreed to in writing, software
+ *  distributed under the License is distributed on an "AS IS" BASIS,
+ *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ *  See the License for the specific language governing permissions and
+ *  limitations under the License.
+ *
+ *=========================================================================*/
 #ifndef __cudaInlineFunctions_h
 #define __cudaInlineFunctions_h
 
@@ -108,29 +112,29 @@ inline void cudaMemset( T* dst, int value, size_t nof_elems )
 
 
 template <typename T, typename Q>
-inline cudaError_t cudaMemcpyToSymbol( T& dst, const Q& src,
+inline cudaError_t cudaMemcpyToSymbol( const T& dst, const Q& src,
   cudaMemcpyKind direction )
 {
-  cudaError err = ::cudaMemcpyToSymbol( dst, &src, sizeof(dst), 0, direction );
+  cudaError err = ::cudaMemcpyToSymbol( &dst, &src, sizeof(dst), 0, direction );
   cudaCheckMsg( "cudaMemcpyToSymbol failed!" );
   return err;
 }
 
 
 template <typename T>
-inline cudaError_t cudaBindTextureToArray( T& tex, cudaArray* array,
+inline cudaError_t cudaBindTextureToArray( const T& tex, cudaArray* array,
   const cudaChannelFormatDesc desc )
 {
-  cudaError_t err = ::cudaBindTextureToArray( tex, array, desc );
+  cudaError_t err = ::cudaBindTextureToArray( &tex, array, &desc );
   cudaCheckMsg( "cudaBindTextureToArray failed!" );
   return err;
 }
 
 
 template <typename T>
-inline cudaError_t cudaUnbindTexture( T& tex )
+inline cudaError_t cudaUnbindTexture( const T& tex )
 {
-  cudaError_t err = ::cudaUnbindTexture( tex );
+  cudaError_t err = ::cudaUnbindTexture( &tex );
   cudaCheckMsg( "cudaUnbindTexture failed!" );
   return err;
 }
