@@ -1,16 +1,20 @@
-/*======================================================================
-
-  This file is part of the elastix software.
-
-  Copyright (c) University Medical Center Utrecht. All rights reserved.
-  See src/CopyrightElastix.txt or http://elastix.isi.uu.nl/legal.php for
-  details.
-
-     This software is distributed WITHOUT ANY WARRANTY; without even
-     the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
-     PURPOSE. See the above copyright notices for more information.
-
-======================================================================*/
+/*=========================================================================
+ *
+ *  Copyright UMC Utrecht and contributors
+ *
+ *  Licensed under the Apache License, Version 2.0 (the "License");
+ *  you may not use this file except in compliance with the License.
+ *  You may obtain a copy of the License at
+ *
+ *        http://www.apache.org/licenses/LICENSE-2.0.txt
+ *
+ *  Unless required by applicable law or agreed to in writing, software
+ *  distributed under the License is distributed on an "AS IS" BASIS,
+ *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ *  See the License for the specific language governing permissions and
+ *  limitations under the License.
+ *
+ *=========================================================================*/
 #ifndef __itkAdvancedImageToImageMetric_h
 #define __itkAdvancedImageToImageMetric_h
 
@@ -228,13 +232,17 @@ public:
 
   /** You may specify a scaling vector for the moving image derivatives.
    * If the UseMovingImageDerivativeScales is true, the moving image derivatives
-   * are multiplied by the moving image derivative scales (elementwise)
+   * are multiplied by the moving image derivative scales (element-wise)
    * You may use this to avoid deformations in the z-dimension, for example,
    * by setting the moving image derivative scales to (1,1,0).
    * This is a rather experimental feature. In most cases you do not need it.
    */
   itkSetMacro( UseMovingImageDerivativeScales, bool );
   itkGetConstMacro( UseMovingImageDerivativeScales, bool );
+
+  itkSetMacro( ScaleGradientWithRespectToMovingImageOrientation, bool );
+  itkGetConstMacro( ScaleGradientWithRespectToMovingImageOrientation, bool );
+
   itkSetMacro( MovingImageDerivativeScales, MovingImageDerivativeScalesType );
   itkGetConstReferenceMacro( MovingImageDerivativeScales, MovingImageDerivativeScalesType );
 
@@ -405,7 +413,6 @@ protected:
     SizeValueType         st_NumberOfPixelsCounted;
     MeasureType           st_Value;
     DerivativeType        st_Derivative;
-    TransformJacobianType st_TransformJacobian;
   };
   itkPadStruct( ITK_CACHE_LINE_ALIGNMENT, GetValueAndDerivativePerThreadStruct,
     PaddedGetValueAndDerivativePerThreadStruct );
@@ -463,7 +470,10 @@ protected:
 
   /** Methods to support transforms with sparse Jacobians, like the BSplineTransform **********/
 
-  /** Check if the transform is an AdvancedTransform. Called by Initialize. */
+  /** Check if the transform is an AdvancedTransform. Called by Initialize.
+   * If so, we can speed up derivative calculations by only inspecting
+   * the parameters in the support region of a point.
+   */
   virtual void CheckForAdvancedTransform( void );
 
   /** Check if the transform is a B-spline. Called by Initialize. */
@@ -522,13 +532,15 @@ private:
   void operator=( const Self & );             // purposely not implemented
 
   /** Private member variables. */
-  bool                            m_UseImageSampler;
-  double                          m_FixedLimitRangeRatio;
-  double                          m_MovingLimitRangeRatio;
-  bool                            m_UseFixedImageLimiter;
-  bool                            m_UseMovingImageLimiter;
-  double                          m_RequiredRatioOfValidSamples;
-  bool                            m_UseMovingImageDerivativeScales;
+  bool   m_UseImageSampler;
+  double m_FixedLimitRangeRatio;
+  double m_MovingLimitRangeRatio;
+  bool   m_UseFixedImageLimiter;
+  bool   m_UseMovingImageLimiter;
+  double m_RequiredRatioOfValidSamples;
+  bool   m_UseMovingImageDerivativeScales;
+  bool   m_ScaleGradientWithRespectToMovingImageOrientation;
+
   MovingImageDerivativeScalesType m_MovingImageDerivativeScales;
 
 };
