@@ -1,19 +1,20 @@
 /*=========================================================================
-
-Program:   Insight Segmentation & Registration Toolkit
-Module:    $RCSfile: itkMevisDicomTiffImageIO.cxx,v $
-Language:  C++
-Date:      $Date: 2009/10/03 15:37:40 $
-Version:   $Revision: 1.51 $
-
-Copyright (c) Insight Software Consortium. All rights reserved.
-See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
-
-This software is distributed WITHOUT ANY WARRANTY; without even
-the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
-PURPOSE.  See the above copyright notices for more information.
-
-=========================================================================*/
+ *
+ *  Copyright UMC Utrecht and contributors
+ *
+ *  Licensed under the Apache License, Version 2.0 (the "License");
+ *  you may not use this file except in compliance with the License.
+ *  You may obtain a copy of the License at
+ *
+ *        http://www.apache.org/licenses/LICENSE-2.0.txt
+ *
+ *  Unless required by applicable law or agreed to in writing, software
+ *  distributed under the License is distributed on an "AS IS" BASIS,
+ *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ *  See the License for the specific language governing permissions and
+ *  limitations under the License.
+ *
+ *=========================================================================*/
 #ifdef _MSC_VER
 #pragma warning ( disable : 4786 )
 #endif
@@ -75,11 +76,11 @@ MevisDicomTiffImageIO
   m_TileLength( 0 ),
   m_TileDepth( 0 ),
   m_NumberOfTiles( 0 ),
-  m_RescaleSlope( NumericTraits< double >::One ),
-  m_RescaleIntercept( NumericTraits< double >::Zero ),
-  m_GantryTilt( NumericTraits< double >::Zero ),
-  m_EstimatedMinimum( NumericTraits< double >::Zero ),
-  m_EstimatedMaximum( NumericTraits< double >::Zero )
+  m_RescaleSlope( NumericTraits< double >::OneValue() ),
+  m_RescaleIntercept( NumericTraits< double >::ZeroValue() ),
+  m_GantryTilt( NumericTraits< double >::ZeroValue() ),
+  m_EstimatedMinimum( NumericTraits< double >::ZeroValue() ),
+  m_EstimatedMaximum( NumericTraits< double >::ZeroValue() )
 {
   //this->SetNumberOfDimensions(4);
   this->SetFileType( Binary );
