@@ -1,16 +1,21 @@
-/*======================================================================
+/*=========================================================================
+ *
+ *  Copyright UMC Utrecht and contributors
+ *
+ *  Licensed under the Apache License, Version 2.0 (the "License");
+ *  you may not use this file except in compliance with the License.
+ *  You may obtain a copy of the License at
+ *
+ *        http://www.apache.org/licenses/LICENSE-2.0.txt
+ *
+ *  Unless required by applicable law or agreed to in writing, software
+ *  distributed under the License is distributed on an "AS IS" BASIS,
+ *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ *  See the License for the specific language governing permissions and
+ *  limitations under the License.
+ *
+ *=========================================================================*/
 
-This file is part of the elastix software.
-
-Copyright (c) University Medical Center Utrecht. All rights reserved.
-See src/CopyrightElastix.txt or http://elastix.isi.uu.nl/legal.php for
-details.
-
-This software is distributed WITHOUT ANY WARRANTY; without even
-the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
-PURPOSE. See the above copyright notices for more information.
-
-======================================================================*/
 #ifndef __itkParameterFileParser_cxx
 #define __itkParameterFileParser_cxx
 
@@ -363,7 +368,7 @@ ParameterFileParser
   std::string::const_iterator it;
   unsigned int                index = 0;
   numQuotes = 0;
-  for( it = line.begin(); it < line.end(); it++ )
+  for( it = line.begin(); it < line.end(); ++it )
   {
     if( *it == '"' )
     {
