@@ -1,16 +1,20 @@
-/*======================================================================
-
-  This file is part of the elastix software.
-
-  Copyright (c) University Medical Center Utrecht. All rights reserved.
-  See src/CopyrightElastix.txt or http://elastix.isi.uu.nl/legal.php for
-  details.
-
-     This software is distributed WITHOUT ANY WARRANTY; without even
-     the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
-     PURPOSE. See the above copyright notices for more information.
-
-======================================================================*/
+/*=========================================================================
+ *
+ *  Copyright UMC Utrecht and contributors
+ *
+ *  Licensed under the Apache License, Version 2.0 (the "License");
+ *  you may not use this file except in compliance with the License.
+ *  You may obtain a copy of the License at
+ *
+ *        http://www.apache.org/licenses/LICENSE-2.0.txt
+ *
+ *  Unless required by applicable law or agreed to in writing, software
+ *  distributed under the License is distributed on an "AS IS" BASIS,
+ *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ *  See the License for the specific language governing permissions and
+ *  limitations under the License.
+ *
+ *=========================================================================*/
 #ifndef __itkAdvancedCombinationTransform_h
 #define __itkAdvancedCombinationTransform_h
 
@@ -73,7 +77,9 @@ public:
   /** Typedefs inherited from Superclass.*/
   typedef typename Superclass::ScalarType                    ScalarType;
   typedef typename Superclass::ParametersType                ParametersType;
+  typedef typename Superclass::ParametersValueType           ParametersValueType;
   typedef typename Superclass::NumberOfParametersType        NumberOfParametersType;
+  typedef typename Superclass::DerivativeType                DerivativeType;
   typedef typename Superclass::JacobianType                  JacobianType;
   typedef typename Superclass::InputVectorType               InputVectorType;
   typedef typename Superclass::OutputVectorType              OutputVectorType;
@@ -92,6 +98,8 @@ public:
   typedef typename Superclass::InverseTransformBaseType      InverseTransformBaseType;
   typedef typename Superclass::InverseTransformBasePointer   InverseTransformBasePointer;
   typedef typename Superclass::TransformCategoryType         TransformCategoryType;
+  typedef typename Superclass::MovingImageGradientType       MovingImageGradientType;
+  typedef typename Superclass::MovingImageGradientValueType  MovingImageGradientValueType;
 
   /** Transform typedefs for the from Superclass. */
   typedef typename Superclass::TransformType   TransformType;
@@ -237,6 +245,13 @@ public:
     JacobianType & j,
     NonZeroJacobianIndicesType & nonZeroJacobianIndices ) const;
 
+  /** Compute the inner product of the Jacobian with the moving image gradient. */
+  virtual void EvaluateJacobianWithImageGradientProduct(
+    const InputPointType & ipp,
+    const MovingImageGradientType & movingImageGradient,
+    DerivativeType & imageJacobian,
+    NonZeroJacobianIndicesType & nonZeroJacobianIndices ) const;
+
   /** Compute the spatial Jacobian of the transformation. */
   virtual void GetSpatialJacobian(
     const InputPointType & ipp,
@@ -283,6 +298,11 @@ public:
     const InputPointType &,
     JacobianType &,
     NonZeroJacobianIndicesType & ) const;
+  typedef void (Self::* EvaluateJacobianWithImageGradientProductFunctionPointer)(
+    const InputPointType &,
+    const MovingImageGradientType &,
+    DerivativeType &,
+    NonZeroJacobianIndicesType & ) const;
   typedef void (Self::* GetSpatialJacobianFunctionPointer)(
     const InputPointType &,
     SpatialJacobianType & ) const;
@@ -346,6 +366,7 @@ protected:
 
   /** More of these. */
   GetSparseJacobianFunctionPointer             m_SelectedGetSparseJacobianFunction;
+  EvaluateJacobianWithImageGradientProductFunctionPointer m_SelectedEvaluateJacobianWithImageGradientProductFunction;
   GetSpatialJacobianFunctionPointer            m_SelectedGetSpatialJacobianFunction;
   GetSpatialHessianFunctionPointer             m_SelectedGetSpatialHessianFunction;
   GetJacobianOfSpatialJacobianFunctionPointer  m_SelectedGetJacobianOfSpatialJacobianFunction;
@@ -405,6 +426,40 @@ protected:
     JacobianType &,
     NonZeroJacobianIndicesType & ) const;
 
+  /** ************************************************
+   * Methods to compute the inner product of the Jacobian with the moving image gradient.
+   */
+
+  /** ADDITION: \f$J(x) = J_1(x)\f$ */
+  inline void EvaluateJacobianWithImageGradientProductUseAddition(
+    const InputPointType &,
+    const MovingImageGradientType &,
+    DerivativeType &,
+    NonZeroJacobianIndicesType & ) const;
+
+  /** COMPOSITION: \f$J(x) = J_1( T_0(x) )\f$
+   * \warning: assumes that input and output point type are the same.
+   */
+  inline void EvaluateJacobianWithImageGradientProductUseComposition(
+    const InputPointType &,
+    const MovingImageGradientType &,
+    DerivativeType &,
+    NonZeroJacobianIndicesType & ) const;
+
+  /** CURRENT ONLY: \f$J(x) = J_1(x)\f$ */
+  inline void EvaluateJacobianWithImageGradientProductNoInitialTransform(
+    const InputPointType &,
+    const MovingImageGradientType &,
+    DerivativeType &,
+    NonZeroJacobianIndicesType & ) const;
+
+  /** NO CURRENT TRANSFORM SET: throw an exception. */
+  inline void EvaluateJacobianWithImageGradientProductNoCurrentTransform(
+    const InputPointType &,
+    const MovingImageGradientType &,
+    DerivativeType &,
+    NonZeroJacobianIndicesType & ) const;
+
   /** ************************************************
    * Methods to compute the spatial Jacobian.
    */
