@@ -1,23 +1,26 @@
-/*======================================================================
-
-  This file is part of the elastix software.
-
-  Copyright (c) University Medical Center Utrecht. All rights reserved.
-  See src/CopyrightElastix.txt or http://elastix.isi.uu.nl/legal.php for
-  details.
-
-     This software is distributed WITHOUT ANY WARRANTY; without even
-     the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
-     PURPOSE. See the above copyright notices for more information.
-
-======================================================================*/
+/*=========================================================================
+ *
+ *  Copyright UMC Utrecht and contributors
+ *
+ *  Licensed under the Apache License, Version 2.0 (the "License");
+ *  you may not use this file except in compliance with the License.
+ *  You may obtain a copy of the License at
+ *
+ *        http://www.apache.org/licenses/LICENSE-2.0.txt
+ *
+ *  Unless required by applicable law or agreed to in writing, software
+ *  distributed under the License is distributed on an "AS IS" BASIS,
+ *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ *  See the License for the specific language governing permissions and
+ *  limitations under the License.
+ *
+ *=========================================================================*/
 #ifndef __elxCorrespondingPointsEuclideanDistanceMetric_H__
 #define __elxCorrespondingPointsEuclideanDistanceMetric_H__
 
 #include "elxIncludes.h" // include first to avoid MSVS warning
 #include "itkCorrespondingPointsEuclideanDistancePointMetric.h"
 
-#include "elxTimer.h"
 
 namespace elastix
 {
@@ -114,10 +117,6 @@ public:
   typedef FixedPointSetType PointSetType;
   typedef FixedImageType    ImageType;
 
-  /** Typedef for timer. */
-  typedef tmr::Timer         TimerType;
-  typedef TimerType::Pointer TimerPointer;
-
   /** Sets up a timer to measure the initialization time and calls the
    * Superclass' implementation.
    */
