@@ -1,23 +1,26 @@
-/*======================================================================
-
-  This file is part of the elastix software.
-
-  Copyright (c) University Medical Center Utrecht. All rights reserved.
-  See src/CopyrightElastix.txt or http://elastix.isi.uu.nl/legal.php for
-  details.
-
-     This software is distributed WITHOUT ANY WARRANTY; without even
-     the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
-     PURPOSE. See the above copyright notices for more information.
-
-======================================================================*/
+/*=========================================================================
+ *
+ *  Copyright UMC Utrecht and contributors
+ *
+ *  Licensed under the Apache License, Version 2.0 (the "License");
+ *  you may not use this file except in compliance with the License.
+ *  You may obtain a copy of the License at
+ *
+ *        http://www.apache.org/licenses/LICENSE-2.0.txt
+ *
+ *  Unless required by applicable law or agreed to in writing, software
+ *  distributed under the License is distributed on an "AS IS" BASIS,
+ *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ *  See the License for the specific language governing permissions and
+ *  limitations under the License.
+ *
+ *=========================================================================*/
 #ifndef __elxKNNGraphAlphaMutualInformationMetric_H__
 #define __elxKNNGraphAlphaMutualInformationMetric_H__
 
 #include "elxIncludes.h" // include first to avoid MSVS warning
 #include "itkKNNGraphAlphaMutualInformationImageToImageMetric.h"
 
-#include "elxTimer.h"
 
 namespace elastix
 {
@@ -141,11 +144,6 @@ public:
   typedef FixedImageType  FixedFeatureImageType;
   typedef MovingImageType MovingFeatureImageType;
 
-  /** Typedef for timer. */
-  typedef tmr::Timer TimerType;
-  /** Typedef for timer. */
-  typedef TimerType::Pointer TimerPointer;
-
   /** Execute stuff before the registration:
    * \li Set the alpha from alpha - MI.
    * \li Set the number of fixed feature images.
@@ -159,17 +157,17 @@ public:
 
   /** Execute stuff before each new pyramid resolution:
    * \li Set the tree type.
-   * \li Set the bucket size, if appropiate.
-   * \li Set the splitting rule, if appropiate.
-   * \li Set the shrinking rule, if appropiate.
+   * \li Set the bucket size, if appropriate.
+   * \li Set the splitting rule, if appropriate.
+   * \li Set the shrinking rule, if appropriate.
    * \li Set the tree searcher type.
    * \li Set the k NearestNeighbours.
    * \li Set the error bound epsilon for ANN search.
-   * \li Set the squared search radius, if appropiate.
+   * \li Set the squared search radius, if appropriate.
    */
   virtual void BeforeEachResolution( void );
 
-  /** Sets up a timer to measure the intialisation time and
+  /** Sets up a timer to measure the initialization time and
    * calls the Superclass' implementation.
    */
   virtual void Initialize( void ) throw ( itk::ExceptionObject );
