@@ -1,21 +1,23 @@
-/*======================================================================
-
-  This file is part of the elastix software.
-
-  Copyright (c) University Medical Center Utrecht. All rights reserved.
-  See src/CopyrightElastix.txt or http://elastix.isi.uu.nl/legal.php for
-  details.
-
-     This software is distributed WITHOUT ANY WARRANTY; without even
-     the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
-     PURPOSE. See the above copyright notices for more information.
-
-======================================================================*/
-
-#ifndef __itkAdaptiveStochasticGradientDescentOptimizer_cxx
-#define __itkAdaptiveStochasticGradientDescentOptimizer_cxx
+/*=========================================================================
+ *
+ *  Copyright UMC Utrecht and contributors
+ *
+ *  Licensed under the Apache License, Version 2.0 (the "License");
+ *  you may not use this file except in compliance with the License.
+ *  You may obtain a copy of the License at
+ *
+ *        http://www.apache.org/licenses/LICENSE-2.0.txt
+ *
+ *  Unless required by applicable law or agreed to in writing, software
+ *  distributed under the License is distributed on an "AS IS" BASIS,
+ *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ *  See the License for the specific language governing permissions and
+ *  limitations under the License.
+ *
+ *=========================================================================*/
 
 #include "itkAdaptiveStochasticGradientDescentOptimizer.h"
+
 #include "vnl/vnl_math.h"
 #include "itkSigmoidImageFilter.h"
 
@@ -39,8 +41,6 @@ AdaptiveStochasticGradientDescentOptimizer
 
 /**
  * ************************** UpdateCurrentTime ********************
- *
- * This function computes the input for the Compute_a function.
  */
 
 void
@@ -82,9 +82,7 @@ AdaptiveStochasticGradientDescentOptimizer
     this->m_CurrentTime += ( this->GetSigmoidMax() + this->GetSigmoidMin() ) / 2.0;
   }
 
-}   // end UpdateCurrentTime()
+} // end UpdateCurrentTime()
 
 
 } // end namespace itk
-
-#endif // end #ifndef __itkAdaptiveStochasticGradientDescentOptimizer_cxx
