@@ -1,16 +1,20 @@
-/*======================================================================
-
-  This file is part of the elastix software.
-
-  Copyright (c) University Medical Center Utrecht. All rights reserved.
-  See src/CopyrightElastix.txt or http://elastix.isi.uu.nl/legal.php for
-  details.
-
-     This software is distributed WITHOUT ANY WARRANTY; without even
-     the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
-     PURPOSE. See the above copyright notices for more information.
-
-======================================================================*/
+/*=========================================================================
+ *
+ *  Copyright UMC Utrecht and contributors
+ *
+ *  Licensed under the Apache License, Version 2.0 (the "License");
+ *  you may not use this file except in compliance with the License.
+ *  You may obtain a copy of the License at
+ *
+ *        http://www.apache.org/licenses/LICENSE-2.0.txt
+ *
+ *  Unless required by applicable law or agreed to in writing, software
+ *  distributed under the License is distributed on an "AS IS" BASIS,
+ *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ *  See the License for the specific language governing permissions and
+ *  limitations under the License.
+ *
+ *=========================================================================*/
 
 #ifndef __itkGenericConjugateGradientOptimizer_cxx
 #define __itkGenericConjugateGradientOptimizer_cxx
@@ -143,8 +147,7 @@ GenericConjugateGradientOptimizer::ResumeOptimization()
   }
 
   /** Test if not by chance we are already converged */
-  bool convergence = false;
-  convergence = this->TestConvergence( false );
+  bool convergence = this->TestConvergence( false );
   if( convergence )
   {
     this->StopOptimization();
@@ -220,8 +223,7 @@ GenericConjugateGradientOptimizer::ResumeOptimization()
       limitCount = 0;
     }
 
-    /** Test if convergence has occured in some other sense */
-    convergence = false;
+    /** Test if convergence has occurred in some other sense */
     convergence = this->TestConvergence( true );
     if( convergence )
     {
