@@ -1,21 +1,23 @@
-/*======================================================================
-
-  This file is part of the elastix software.
-
-  Copyright (c) University Medical Center Utrecht. All rights reserved.
-  See src/CopyrightElastix.txt or http://elastix.isi.uu.nl/legal.php for
-  details.
-
-     This software is distributed WITHOUT ANY WARRANTY; without even
-     the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
-     PURPOSE. See the above copyright notices for more information.
-
-======================================================================*/
-
-#ifndef _itkGradientDescentOptimizer2_txx
-#define _itkGradientDescentOptimizer2_txx
+/*=========================================================================
+ *
+ *  Copyright UMC Utrecht and contributors
+ *
+ *  Licensed under the Apache License, Version 2.0 (the "License");
+ *  you may not use this file except in compliance with the License.
+ *  You may obtain a copy of the License at
+ *
+ *        http://www.apache.org/licenses/LICENSE-2.0.txt
+ *
+ *  Unless required by applicable law or agreed to in writing, software
+ *  distributed under the License is distributed on an "AS IS" BASIS,
+ *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ *  See the License for the specific language governing permissions and
+ *  limitations under the License.
+ *
+ *=========================================================================*/
 
 #include "itkGradientDescentOptimizer2.h"
+
 #include "itkCommand.h"
 #include "itkEventObject.h"
 #include "itkExceptionObject.h"
@@ -41,6 +43,7 @@ GradientDescentOptimizer2
 {
   itkDebugMacro( "Constructor" );
 
+  this->m_Stop               = false;
   this->m_LearningRate       = 1.0;
   this->m_NumberOfIterations = 100;
   this->m_CurrentIteration   = 0;
@@ -51,8 +54,9 @@ GradientDescentOptimizer2
   this->m_UseMultiThread = false;
   this->m_UseOpenMP      = false;
   this->m_UseEigen       = false;
+  //this->m_Threader->SetUseThreadPool( true );
 
-}   // end Constructor
+} // end Constructor
 
 
 /**
@@ -80,12 +84,12 @@ GradientDescentOptimizer2
      << this->m_Gradient;
   os << std::endl;
 
-}   // end PrintSelf
+} // end PrintSelf()
 
 
 /**
-* **************** Start the optimization ********************
-*/
+ * **************** StartOptimization ********************
+ */
 
 void
 GradientDescentOptimizer2
@@ -106,12 +110,12 @@ GradientDescentOptimizer2
   this->SetCurrentPosition( this->GetInitialPosition() );
 
   this->ResumeOptimization();
-}   // end StartOptimization
+} // end StartOptimization()
 
 
 /**
-* ************************ ResumeOptimization *************
-*/
+ * ************************ ResumeOptimization *************
+ */
 
 void
 GradientDescentOptimizer2
@@ -129,7 +133,6 @@ GradientDescentOptimizer2
 
   while( !this->m_Stop )
   {
-
     try
     {
       this->GetScaledValueAndDerivative(
@@ -163,9 +166,9 @@ GradientDescentOptimizer2
       break;
     }
 
-  }   // end while
+  } // end while
 
-}   // end ResumeOptimization()
+} // end ResumeOptimization()
 
 
 /**
@@ -183,12 +186,12 @@ GradientDescentOptimizer2
   /** Pass exception to caller. */
   throw err;
 
-}   // end MetricErrorResponse()
+} // end MetricErrorResponse()
 
 
 /**
-* ***************** Stop optimization ************************
-*/
+ * ***************** StopOptimization ************************
+ */
 
 void
 GradientDescentOptimizer2
@@ -198,12 +201,11 @@ GradientDescentOptimizer2
 
   this->m_Stop = true;
   this->InvokeEvent( EndEvent() );
-}   // end StopOptimization
+} // end StopOptimization()
 
 
 /**
  * ************ AdvanceOneStep ****************************
- * following the gradient direction
  */
 
 void
@@ -221,20 +223,21 @@ GradientDescentOptimizer2
 
   /** Advance one step. */
   // single-threadedly
-  if( !this->m_UseMultiThread || true )   // for now force single-threaded since it is fastest most of the times
+  if( true )
+  //if( !this->m_UseMultiThread || true )   // for now force single-threaded since it is fastest most of the times
   //if( !this->m_UseMultiThread && false ) // force multi-threaded
   {
     /** Get a reference to the current position. */
     const ParametersType & currentPosition = this->GetScaledCurrentPosition();
 
     /** Update the new position. */
-    for( unsigned int j = 0; j < spaceDimension; j++ )
+    for( unsigned int j = 0; j < spaceDimension; ++j )
     {
       newPosition[ j ] = currentPosition[ j ] - this->m_LearningRate * this->m_Gradient[ j ];
     }
   }
 #ifdef ELASTIX_USE_OPENMP
-  else if( this->m_UseOpenMP && !this->m_UseEigen )
+  else if( true )// this->m_UseOpenMP && !this->m_UseEigen )
   {
     /** Get a reference to the current position. */
     const ParametersType & currentPosition = this->GetScaledCurrentPosition();
@@ -242,7 +245,7 @@ GradientDescentOptimizer2
     /** Update the new position. */
     const int nthreads = static_cast< int >( this->m_Threader->GetNumberOfThreads() );
     omp_set_num_threads( nthreads );
-      #pragma omp parallel for
+    #pragma omp parallel for
     for( int j = 0; j < static_cast< int >( spaceDimension ); j++ )
     {
       newPosition[ j ] = currentPosition[ j ] - this->m_LearningRate * this->m_Gradient[ j ];
@@ -283,7 +286,7 @@ GradientDescentOptimizer2
     const int spaceDim = static_cast< int >( spaceDimension );
     const int nthreads = static_cast< int >( this->m_Threader->GetNumberOfThreads() );
     omp_set_num_threads( nthreads );
-      #pragma omp parallel for
+    #pragma omp parallel for
     for( int i = 0; i < nthreads; i += 1 )
     {
       int threadId = omp_get_thread_num();
@@ -305,17 +308,15 @@ GradientDescentOptimizer2
     temp->t_Optimizer   = this;
 
     /** Call multi-threaded AdvanceOneStep(). */
-    ThreaderType::Pointer local_threader = ThreaderType::New();
-    local_threader->SetNumberOfThreads( this->m_Threader->GetNumberOfThreads() );
-    local_threader->SetSingleMethod( AdvanceOneStepThreaderCallback, (void *)( temp ) );
-    local_threader->SingleMethodExecute();
+    this->m_Threader->SetSingleMethod( AdvanceOneStepThreaderCallback, (void *)( temp ) );
+    this->m_Threader->SingleMethodExecute();
 
     delete temp;
   }
 
   this->InvokeEvent( IterationEvent() );
 
-}   // end AdvanceOneStep()
+} // end AdvanceOneStep()
 
 
 /**
@@ -373,5 +374,3 @@ GradientDescentOptimizer2
 
 
 } // end namespace itk
-
-#endif
