@@ -1,16 +1,20 @@
-/*======================================================================
-
-  This file is part of the elastix software.
-
-  Copyright (c) University Medical Center Utrecht. All rights reserved.
-  See src/CopyrightElastix.txt or http://elastix.isi.uu.nl/legal.php for
-  details.
-
-     This software is distributed WITHOUT ANY WARRANTY; without even
-     the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
-     PURPOSE. See the above copyright notices for more information.
-
-======================================================================*/
+/*=========================================================================
+ *
+ *  Copyright UMC Utrecht and contributors
+ *
+ *  Licensed under the Apache License, Version 2.0 (the "License");
+ *  you may not use this file except in compliance with the License.
+ *  You may obtain a copy of the License at
+ *
+ *        http://www.apache.org/licenses/LICENSE-2.0.txt
+ *
+ *  Unless required by applicable law or agreed to in writing, software
+ *  distributed under the License is distributed on an "AS IS" BASIS,
+ *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ *  See the License for the specific language governing permissions and
+ *  limitations under the License.
+ *
+ *=========================================================================*/
 #ifndef __itkCombinationImageToImageMetric_h
 #define __itkCombinationImageToImageMetric_h
 
@@ -221,8 +225,8 @@ public:
   /** Get the last computed derivative magnitude for metric i. */
   double GetMetricDerivativeMagnitude( unsigned int pos ) const;
 
-  /** Get the last computed derivative magnitude for metric i. */
-  std::size_t GetMetricComputationTime( unsigned int pos ) const;
+  /** Get the last computed computation time for metric i. */
+  double GetMetricComputationTime( unsigned int pos ) const;
 
   /**
    * Set/Get functions for the metric components
@@ -424,7 +428,7 @@ protected:
   mutable std::vector< MeasureType >             m_MetricValues;
   mutable std::vector< DerivativeType >          m_MetricDerivatives;
   mutable std::vector< double >                  m_MetricDerivativesMagnitude;
-  mutable std::vector< std::size_t >             m_MetricComputationTime;
+  mutable std::vector< double >                  m_MetricComputationTime;
 
   /** Dummy image region and derivatives. */
   FixedImageRegionType m_NullFixedImageRegion;
@@ -452,7 +456,7 @@ private:
     std::vector< SingleValuedCostFunctionPointer > st_MetricsIterator;
     typename std::vector< MeasureType >::iterator st_MetricValuesIterator;
     typename std::vector< DerivativeType >::iterator st_MetricDerivativesIterator;
-    std::vector< std::size_t > st_MetricComputationTime;
+    std::vector< double > st_MetricComputationTime;
     ParametersType *           st_Parameters;
   };
 
