@@ -1,16 +1,20 @@
-/*======================================================================
-
-  This file is part of the elastix software.
-
-  Copyright (c) University Medical Center Utrecht. All rights reserved.
-  See src/CopyrightElastix.txt or http://elastix.isi.uu.nl/legal.php for
-  details.
-
-     This software is distributed WITHOUT ANY WARRANTY; without even
-     the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
-     PURPOSE. See the above copyright notices for more information.
-
-======================================================================*/
+/*=========================================================================
+ *
+ *  Copyright UMC Utrecht and contributors
+ *
+ *  Licensed under the Apache License, Version 2.0 (the "License");
+ *  you may not use this file except in compliance with the License.
+ *  You may obtain a copy of the License at
+ *
+ *        http://www.apache.org/licenses/LICENSE-2.0.txt
+ *
+ *  Unless required by applicable law or agreed to in writing, software
+ *  distributed under the License is distributed on an "AS IS" BASIS,
+ *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ *  See the License for the specific language governing permissions and
+ *  limitations under the License.
+ *
+ *=========================================================================*/
 
 /** If running on a Windows-system, include "windows.h".
  *  This is to set the priority, but which does not work on cygwin.
@@ -21,9 +25,14 @@
 #endif
 
 #include "elxElastixMain.h"
+
 #include "elxMacro.h"
 #include "itkMultiThreader.h"
 
+#ifdef ELASTIX_USE_OPENCL
+#include "itkOpenCLSetup.h"
+#endif
+
 namespace elastix
 {
 
@@ -156,8 +165,8 @@ ElastixMain::ComponentDatabasePointer ElastixMain::s_CDB             = 0;
 ElastixMain::ComponentLoaderPointer   ElastixMain::s_ComponentLoader = 0;
 
 /**
-* ********************** Destructor ****************************
-*/
+ * ********************** Destructor ****************************
+ */
 
 ElastixMain::~ElastixMain()
 {
@@ -180,7 +189,7 @@ ElastixMain
   int dummy = this->m_Configuration->Initialize( argmap );
   if( dummy )
   {
-    xout[ "error" ] << "ERROR: Something went wrong during initialisation "
+    xout[ "error" ] << "ERROR: Something went wrong during initialization "
                     << "of the configuration object." << std::endl;
   }
 
@@ -202,7 +211,7 @@ ElastixMain
   int dummy = this->m_Configuration->Initialize( argmap, inputMap );
   if( dummy )
   {
-    xout[ "error" ] << "ERROR: Something went wrong during initialisation of the configuration object." << std::endl;
+    xout[ "error" ] << "ERROR: Something went wrong during initialization of the configuration object." << std::endl;
   }
 
 } // end EnterCommandLineArguments()
@@ -229,7 +238,7 @@ ElastixMain
     int dummy = this->m_Configurations[ i ]->Initialize( argmap, inputMaps[ i ] );
     if( dummy )
     {
-      xout[ "error" ] << "ERROR: Something went wrong during initialisation of configuration object " << i << "." << std::endl;
+      xout[ "error" ] << "ERROR: Something went wrong during initialization of configuration object " << i << "." << std::endl;
     }
   }
 
@@ -242,7 +251,7 @@ ElastixMain
  * **************************** Run *****************************
  *
  * Assuming EnterCommandLineParameters has already been invoked.
- * or that m_Configuration is initialised in another way.
+ * or that m_Configuration is initialized in another way.
  */
 
 int
@@ -274,6 +283,24 @@ ElastixMain::Run( void )
     return errorCode;
   }
 
+  /** Create OpenCL context and logger here. */
+#ifdef ELASTIX_USE_OPENCL
+  std::string errorMessage = "";
+  bool errorCreatingContext = itk::CreateOpenCLContext( errorMessage );
+  if( errorCreatingContext )
+  {
+    /** Report and disable the GPU by releasing the context. */
+    elxout << errorMessage << std::endl;
+    elxout << "OpenCL processing is disabled." << std::endl;
+
+    itk::OpenCLContext::Pointer context = itk::OpenCLContext::GetInstance();
+    context->Release();
+  }
+
+  /** Create a log file. */
+  itk::CreateOpenCLLogger( "elastix", this->m_Configuration->GetCommandLineArgument( "-out" ) );
+#endif
+
   /** Set some information in the ElastixBase. */
   this->GetElastixBase()->SetConfiguration( this->m_Configuration );
   this->GetElastixBase()->SetComponentDatabase( this->s_CDB );
@@ -861,8 +888,7 @@ void
 ElastixMain::SetProcessPriority( void ) const
 {
   /** If wanted, set the priority of this process high or below normal. */
-  std::string processPriority = "";
-  processPriority = this->m_Configuration->GetCommandLineArgument( "-priority" );
+  std::string processPriority = this->m_Configuration->GetCommandLineArgument( "-priority" );
   if( processPriority == "high" )
   {
     #if defined( _WIN32 ) && !defined( __CYGWIN__ )
@@ -910,8 +936,7 @@ void
 ElastixMain::SetMaximumNumberOfThreads( void ) const
 {
   /** Get the number of threads from the command line. */
-  std::string maximumNumberOfThreadsString = "";
-  maximumNumberOfThreadsString
+  std::string maximumNumberOfThreadsString
     = this->m_Configuration->GetCommandLineArgument( "-threads" );
 
   /** If supplied, set the maximum number of threads. */
